/* LSAGPI                                       */
/* Desarrollado por Miguel Angel Pescador Santirso  */
/* mescadorsantirso@gmail.com                       */

/* LICENCIA X11/MIT
Copyright (c) 2010 Miguel Angel Pescador Santirso

Se autoriza, de forma gratuita, a cualquier
persona que ha obtenido una copia de este software y
archivos asociados de documentación (el "Software"), para tratar en el
Software sin restricción, incluyendo sin ninguna limitación en lo que concierne
los derechos para usar, copiar, modificar, fusionar, publicar,
distribuir, sublicenciar, y / o vender copias de este
Software, y para permitir a las personas que usan el Software para
hacerlo, con sujeción a las siguientes condiciones:

El aviso de copyright anterior y este aviso de permiso
se incluirá en todas las copias o partes sustanciales de
este Software.

EL SOFTWARE SE ENTREGA "TAL CUAL", SIN GARANTÍA DE NINGÚN
TIPO, EXPRESA o implícita, no limitado a la GARANTÍAS DE
COMERCIALIZACIÓN, CAPACIDAD DE HACER Y DE NO INFRACCIÓN DE COPYRIGHT. EN NINGÚN
CASO LOS AUTORES O TITULARES DEL COPYRIGHT SERÁN RESPONSABLES DE
NINGUNA RECLAMACIÓN, daños o OTRAS RESPONSABILIDADES,
YA SEA EN UN LITIGIO, agravio o DE OTRO MODO,
DERIVADAS DE, FUERA DE O EN CONEXION CON EL
SOFTWARE SU UTILIZACIÓN U OTRAS OPERACIONES EN EL SOFTWARE.
*/



package lsagpi;

import java.awt.Color;
import java.awt.Font;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.Image;
import java.awt.Toolkit;
import java.awt.event.ActionEvent;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.awt.event.MouseMotionListener;
import java.awt.geom.AffineTransform;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;
import java.net.MalformedURLException;
import java.util.Vector;
import javax.sound.midi.InvalidMidiDataException;
import javax.sound.midi.MidiSystem;
import javax.sound.midi.MidiUnavailableException;
import javax.sound.midi.MidiUnavailableException;
import javax.sound.midi.Sequence;
import javax.sound.midi.Sequencer;
import javax.sound.sampled.Clip;
import javax.swing.JPanel;

/**
 * Clase que dibuja la aventura e implementa todos los metodos necesarios.
 * @author Miguel Angel Pescador Santirso
 */
public class Aventura extends JPanel implements MouseListener, MouseMotionListener{
int parametros=0;
Vector verbos;
Vector room;
int cursorx;
int cursory;
boolean fijarverbo;
int pasosverbo=0;
Verbo verboActual;
Verbo verbodefecto;
Vector globales;
Vector locales;
Cuarto habitacionActual;
Image buffer;
Graphics bb;
String personaje;
Font fuente;
Sistema sis;
boolean sonido=false;
Sequence sequence;
Sequencer sequencer= null;
/**
 * Constructor básico de la Aventura
 */
public Aventura(){
    addMouseListener(this);
    addMouseMotionListener(this);
}
/**
 * Constructor real de la aventura.
 * @param sistema Valores del Sistema de aventura.
 * @param habitaciones Cuartos que contendra la aventura.
 * @param accionesglobales Acciones que se aplican a todas las habitaciones.
 */
public Aventura(Sistema sistema, Vector habitaciones, Vector accionesglobales){
    addMouseListener(this);
    addMouseMotionListener(this);
    fijarParametros(sistema,habitaciones,accionesglobales);
    //buffer=this.createImage(width, height);
    //bb=buffer.getGraphics();
   
    
    //buffer = createImage(size().width, size().height);

}
/**
 * Fija los parametros del Panel de Aventura.
 * @param sistema Clase Sistema con las preferencias del sistema.
 * @param habitaciones Vector de habitaciones.
 * @param accionesglobales Vector de acciones globales.
 */
public void fijarParametros(Sistema sistema, Vector habitaciones, Vector accionesglobales){
     parametros=1;
    verbos=sistema.getVerbos();
    room=habitaciones;
    globales=accionesglobales;
    personaje=sistema.personaje;
    fuente=sistema.fuente;
    sis=sistema;
    if(sis.cursor!=null){
    Toolkit toolkit=this.getToolkit();
    this.setCursor(toolkit.createCustomCursor(sis.cursor.getImage(),sis.puntocursor,""));
    }
    for (int i=0;i<verbos.size();i++){
        if((((Verbo)verbos.get(i)).nombre).equals(sistema.verbodefecto)){
            verbodefecto=(Verbo)verbos.get(i);
    }
    }

}
/**
 * Redibuja la pantalla de aventura
 */
    @SuppressWarnings("static-access")
public void redibujar(){
         
         this.setDoubleBuffered(true);
         this.setOpaque(true);
    //pintarSistema(g);
        if (parametros==0){
            Image img = Toolkit.getDefaultToolkit().getImage("images\\se.jpg");
            bb.drawImage(img, 0, 0, this);
        }else{
            //-->Seleccion de Habitacion NEXT
            for(int i=0;i<room.size();i++){
               // System.out.println(((Cuarto)room.elementAt(i)).nombre);
                if(((Cuarto)room.elementAt(i)).nombre.equals(sis.habitacionInicial)){
                    habitacionActual=(Cuarto)room.elementAt(i);
                }
            }
           
            try {
            
            if (sonido==false && !habitacionActual.sonidofondo.equals("")){
            sonido=true;
            sequence = MidiSystem.getSequence(new File(habitacionActual.sonidofondo));
            System.out.println("Reproduciendo secuencia midi:"+habitacionActual.sonidofondo);
            // Create a sequencer for the sequence
            sequencer = MidiSystem.getSequencer();
            sequencer.open();
            sequencer.setSequence(sequence);
            // Start playing
            sequencer.start();
            }else if(sonido==true && habitacionActual.sonidofondo.equals("")){
                sequencer.stop();
                sonido=false;
            }
        } catch (MalformedURLException e) { } catch (IOException e) { } catch (MidiUnavailableException e) { } catch (InvalidMidiDataException e) { }
        
            locales=(habitacionActual.acciones);
            //pintarSistema();
            pintarHabitacion(habitacionActual);
            if(habitacionActual.nombre.indexOf("intro")==-1){
                pintarSistema();
                if(sis.paneldeconversacion==false){
                    pintarInventario(sis.personajeelemento, bb);
                }else{
                    pintarPaneldeConversacion();
                }
            }
            

        }
}
/*public void paint(Graphics g){
    update( g );
}*/
/**
 * Pinta los componentes de la aventura
 * @param g Graphics, cursor de dibujo de la aventura.
 */
    @Override
protected void paintComponent(Graphics g) {
    //super.paintComponent (g);
        buffer= createImage(getSize().width,getSize().height);
        bb = buffer.getGraphics();
        update( g );

 }
 /**
 * Actualiza los componentes de la aventura
 * @param g Graphics, cursor de dibujo de la aventura.
 */
   @Override
  public void update(Graphics g){
    redibujar();
    g.drawImage( buffer, 0, 0, this );

      //g.clipRect(0,0,640,320);
  //paintComponent(g);
}
   
/**
 * Dibuja el sistema SCUMM.
 */
public void pintarSistema(){
    Graphics2D g=(Graphics2D)bb;
    g.setFont(fuente);
    g.setColor(Color.BLACK);
    //g.fill3DRect(0, 0, 640, 300, false);
    g.setColor(Color.BLUE);
    //Cuadriculas Verbos y rellenar verbos.
    int k=0;
    for(int i=0;i<180;i=i+88){
        for(int j=320;j<430;j=j+54){
            g.fill3DRect(i, j, 87, 53, false);
            if(((Verbo)verbos.elementAt(k)).getImagen()!=null){
                g.drawImage(((Verbo)verbos.elementAt(k)).getImagen(), i, j, this);

            }else{
                g.drawString(((Verbo)verbos.elementAt(k)).getEtiqueta(),i+10, j+20);
        }
            k++;
        }
    }
    
    //Subir bajar Elementos
    if(sis.inventario.imagenes.isEmpty()){
        g.setColor(Color.BLUE);
        g.fill3DRect(261, 320, 30, 82,false);
        g.fill3DRect(261, 402, 30, 82,false);
        g.setColor(Color.RED );
        g.drawString("▲",270, 372);
        g.drawString("▼",270, 452);
        g.setColor(Color.BLUE);
    }else{
        g.drawImage(sis.inventario.getImagen(0),261,320, this);
        g.drawImage(sis.inventario.getImagen(2),261,402, this);
    }
    //Filas de Elementos
    
    g.setColor(Color.GREEN );
    //zona de estado
    g.fill3DRect(0, 300, 640, 20,false);
    g.setColor(Color.RED );
   
}

/**
 * Dibuja de habitacion actual.
 * @param cuarto Cuarto habitacion actual.
 */
public void pintarHabitacion(Cuarto cuarto){
    Graphics2D h= (Graphics2D)bb;
    if(cuarto.getFondo()!=null){
        int alto=cuarto.getFondo().getImage().getHeight(this);
        int ancho=cuarto.getFondo().getImage().getWidth(this);
        if(habitacionActual.nombre.indexOf("intro")==-1){
            if(alto>sis.PANTALLAVERTICAL){
                alto=alto-sis.PANTALLAVERTICAL;
            }else{alto=0;}
            if(ancho>sis.PANTALLAHORIZONTAL){
                ancho=0;//ancho-sis.PANTALLAHORIZONTAL;
            }else{ancho=0;}
            
            /*if(sis.personajeelemento.posicion[0]>(sis.PANTALLAHORIZONTAL/2)){
                ancho++;}
            */}else{
                ancho=0;
                alto=0;
            }
        h.drawImage(cuarto.getFondo().getImage(), -ancho, -alto, this);
   
        }
    else{
        h.setColor(Color.BLACK);
        h.fill3DRect(0, 0, sis.PANTALLAHORIZONTAL, sis.PANTALLAVERTICAL,false);

    }
    for(int i=0;i<cuarto.elementos.size();i++){
                Elemento a=(Elemento)cuarto.elementos.elementAt(i);
                if(a.nombre.equals(sis.personaje)){
                    sis.personajeelemento=a;
                }
            }
    Vector elem=cuarto.elementos;
    for(int i=0;i<elem.size();i++){
        Elemento a=(Elemento)elem.elementAt(i);
        int[] b=a.getPosicion();
        if(b[2]!=0){
            Image escala=a.getImagen();
            double esc=((double)b[2])/100;

            int escalaAncho = (int)( esc*a.getImagen().getWidth(this) );
            int escalaAlto = (int)( esc*a.getImagen().getHeight(this) );
            BufferedImage imgFinal = new BufferedImage(escalaAncho,escalaAlto,BufferedImage.TYPE_4BYTE_ABGR_PRE );
            AffineTransform tranformador = new AffineTransform();
            tranformador.scale(esc,esc);
            Graphics2D g2 = imgFinal.createGraphics();
            g2.drawImage( escala ,tranformador,this );
            g2.dispose();
            h.drawImage( imgFinal,b[0],b[1]-escalaAlto,this);
            a.setPosicion(b[0],b[1],b[2]);
        }else{
            h.drawImage(a.getImagen(),b[0],b[1]-a.getImagen().getHeight(this),this);
        }
    }
    
    }
/**
 * Dibuja el inventario del personaje actual.
 * @param invelem Elemento Personaje actual.
 * @param hh Graphics, cursos de dibujo.
 */
    public void pintarInventario(Elemento invelem,Graphics hh){
        Vector inventario=new Vector();
        try{
            //Si esta vacio lanza una excepcion.
            inventario=sis.personajeelemento.getElementos();
        }catch(ArrayIndexOutOfBoundsException e){}
        hh.setColor(Color.BLUE);
        if(inventario.isEmpty()){
            for (int i=291;i<580;i=i+70){
                for(int j=320;j<405;j=j+82){
                    hh.fill3DRect(i, j, 70, 82,false);
                }
            }
        }else{
            int k=0;
            int l=inventario.size();
            for (int i=291;i<580;i=i+70){
                for(int j=320;j<405;j=j+82){
                    if(k<l && k<sis.inventario.TAMANO){
                        hh.drawImage(((Elemento)inventario.get(k)).getIcono(),i,j,this);
                    }else{
                    hh.fill3DRect(i, j, 70, 82,false);
                    }
                    k++;
                    }
            }
        
    }}
    /**
    * Dibuja el panel de conversación.
    */
    public void pintarPaneldeConversacion(){
        Graphics2D g=(Graphics2D)bb;
        if(sis.inventario.imagenes.isEmpty()){
        g.setColor(Color.BLUE);
        g.fill3DRect(0, 320, 30, 82,false);
        g.fill3DRect(0, 402, 30, 82,false);
        g.setColor(Color.RED );
        g.drawString("▲",270, 372);
        g.drawString("▼",270, 452);
        g.setColor(Color.BLUE);
    }else{
        g.drawImage(sis.inventario.getImagen(0),0,320, this);
        g.drawImage(sis.inventario.getImagen(2),0,402, this);
    }
        int k=sis.panelconversacion.TAMANO;
        for(int j=320;j<460;j=j+(164/k)){
            g.setColor(Color.BLUE);
            g.fill3DRect(30, j, sis.PANTALLAHORIZONTAL-30, 164/k,false);

        }

    }
    /**
     * Devuelve el cursor del Buffer externo de dibujo.
     * @return Graphics cursor del Doble Buffer.
     */
    public Graphics getDobleBuffer(){
        return bb;
    }
    /**
     * Gestor del evento click del raton.
     * @param e MouseEvent evento del raron.
     */
    public void mouseClicked(MouseEvent e) {      
        
        //repaint();
       if(sis.paneldeconversacion==false){
       if(e.getY()<300 || (e.getY()>300 && e.getX()>261)){
            if(fijarverbo==true){
            parsearVerbo(verboActual,e.getX(),e.getY());
            }else if(fijarverbo==false){
              pasosverbo=1;
              verboActual=verbodefecto;
              parsearVerbo(verboActual,e.getX(),e.getY());
            }
        }//eventos en aventura
        if(e.getY()>300){
            if(e.getX()<261){
                    fijarverbo=true;
                    System.out.println("MouseClicked "+fijarverbo);
               //Zona de verbos
               if(e.getX()<88){
                    
                    if(e.getY()>320 && e.getY()<374){
                        parsearVerbo((Verbo)verbos.elementAt(0),e.getX(),e.getY());
                    }else if(e.getY()<418 && e.getY()>374){
                        parsearVerbo((Verbo)verbos.elementAt(1),e.getX(),e.getY());
                    }else{
                        parsearVerbo((Verbo)verbos.elementAt(2),e.getX(),e.getY());
                    }
                }else if(e.getX()<176){
                    if(e.getY()>320 && e.getY()<374){
                        parsearVerbo((Verbo)verbos.elementAt(3),e.getX(),e.getY());
                    }else if(e.getY()<418 && e.getY()>374){
                        parsearVerbo((Verbo)verbos.elementAt(4),e.getX(),e.getY());
                    }else{
                        parsearVerbo((Verbo)verbos.elementAt(5),e.getX(),e.getY());
                    }
                }else
                {
                    if(e.getY()>320 && e.getY()<374){
                        parsearVerbo((Verbo)verbos.elementAt(6),e.getX(),e.getY());
                    }else if(e.getY()<418 && e.getY()>374){
                        parsearVerbo((Verbo)verbos.elementAt(7),e.getX(),e.getY());
                    }else{
                        parsearVerbo((Verbo)verbos.elementAt(8),e.getX(),e.getY());
                    }
                }
            }}
        //eventos en controles
       }
    }
    /**
     * Gestor del evento pulsacion del raton.
     * @param e MouseEvent evento del raron.
     */
    public void mousePressed(MouseEvent e) {
        
    }
    /**
     * Gestor del evento levantar el dedo del raton.
     * @param e MouseEvent evento del raron.
     */
    public void mouseReleased(MouseEvent e) {
        
    }
    /**
     * Gestor del evento entrada del cursos del raton en la aventura.
     * @param e MouseEvent evento del raron.
     */
    public void mouseEntered(MouseEvent e) {
        this.update(super.getGraphics());
        try{
        if(!habitacionActual.procedimiento.isEmpty()){
                EjecutarAcciones exe=new EjecutarAcciones(sis,((Accion)habitacionActual.procedimiento.get(0)).acciones,room,super.getGraphics(),this);
                //habitacionActual.procedimiento.remove(0);
        }
        }catch(NullPointerException ex){}
    }
    /**
     * Gestor del evento salida del cursos del raton de la aventura.
     * @param e MouseEvent evento del raron.
     */
    public void mouseExited(MouseEvent e) {
        
    }
    /**
     * Gestor del evento arrastre del raton.
     * @param e MouseEvent evento del raron.
     */
    public void mouseDragged(MouseEvent e) {
        
    }
    /**
     * Gestor del evento movimiento del raton.
     * @param e MouseEvent evento del raron.
     */
    public void mouseMoved(MouseEvent e) {
        Graphics2D h=(Graphics2D) super.getGraphics();
        //update(super.getGraphics());
        //repaint();
        //Control de Eventos.
        //System.out.println(habitacionActual.eventos.size());
        try{
        if (sis.paneldeconversacion==false){
        for(int k=0;k<habitacionActual.eventos.size();k++){
            Comparar comp=new Comparar(((Evento)habitacionActual.eventos.get(k)).condicion ,habitacionActual);
            if(comp.getResultado()==true){
                System.out.println("Colision!!!!!!!!");
                EjecutarAcciones exe=new EjecutarAcciones(sis,((Evento)habitacionActual.eventos.get(k)).acciones,room,this.getGraphics(),this);
            }
        }
        cursorx=e.getX();
        cursory=e.getY();
        if(fijarverbo==true){
            DibujarCajas cajas=new DibujarCajas(habitacionActual.elementos,this);
            h.setColor(Color.GREEN );
            h.fill3DRect(0, 300, 640, 20,false);
            h.setColor(Color.RED );
            h.drawString(verboActual.getEtiqueta()+" "+cajas.evaluarPosicion(cursorx, cursory),300, 310);
        }
        else if(fijarverbo==false){
        h.setColor(Color.GREEN );
        h.fill3DRect(0, 300, 640, 20,false);
        if(e.getY()<300){
            DibujarCajas cajas=new DibujarCajas(habitacionActual.elementos,this);
            h.setColor(Color.GREEN );
            h.fill3DRect(0, 300, 640, 20,false);
            h.setColor(Color.RED );
            h.drawString(verbodefecto.getEtiqueta()+" "+cajas.evaluarPosicion(e.getX(), e.getY() ) ,300, 310);
        }//eventos en aventura
        
        if(e.getY()>300){
            //Zona de elementos
            if(e.getX()>261){
                if(e.getY()>320 && e.getY()<402){
                    if(e.getX()>291 && e.getX()<361){
                             int k=0;
                             if (k<sis.personajeelemento.elementos.size()){
                             h.setColor(Color.GREEN );
                             h.fill3DRect(0, 300, 640, 20,false);
                             h.setColor(Color.RED );
                             //System.out.println(((Elemento)sis.personajeelemento.elementos.get(k)).nombre);
                             h.drawString(verbodefecto.getEtiqueta()+" "+((Elemento)sis.personajeelemento.elementos.get(k)).nombre,300, 310);
                             }
                    }
                    if(e.getX()>361 && e.getX()<431){
                             int k=1;
                             if (k<sis.personajeelemento.elementos.size()){
                             h.setColor(Color.GREEN );
                             h.fill3DRect(0, 300, 640, 20,false);
                             h.setColor(Color.RED );
                             //System.out.println(((Elemento)sis.personajeelemento.elementos.get(k)).nombre);
                             h.drawString(verbodefecto.getEtiqueta()+" "+((Elemento)sis.personajeelemento.elementos.get(k)).nombre,300, 310);
                             }
                    }
                    if(e.getX()>431 && e.getX()<501){
                             int k=2;
                             if (k<sis.personajeelemento.elementos.size()){
                             h.setColor(Color.GREEN );
                             h.fill3DRect(0, 300, 640, 20,false);
                             h.setColor(Color.RED );
                             //System.out.println(((Elemento)sis.personajeelemento.elementos.get(k)).nombre);
                             h.drawString(verbodefecto.getEtiqueta()+" "+((Elemento)sis.personajeelemento.elementos.get(k)).nombre,300, 310);
                             }
                    }
                    if(e.getX()>501 && e.getX()<571){
                             int k=3;
                             if (k<sis.personajeelemento.elementos.size()){
                             h.setColor(Color.GREEN );
                             h.fill3DRect(0, 300, 640, 20,false);
                             h.setColor(Color.RED );
                             //System.out.println(((Elemento)sis.personajeelemento.elementos.get(k)).nombre);
                             h.drawString(verbodefecto.getEtiqueta()+" "+((Elemento)sis.personajeelemento.elementos.get(k)).nombre,300, 310);
                             }
                    }
                    if(e.getX()>571 && e.getX()<641){
                             int k=4;
                             if (k<sis.personajeelemento.elementos.size()){
                             h.setColor(Color.GREEN );
                             h.fill3DRect(0, 300, 640, 20,false);
                             h.setColor(Color.RED );
                             //System.out.println(((Elemento)sis.personajeelemento.elementos.get(k)).nombre);
                             h.drawString(verbodefecto.getEtiqueta()+" "+((Elemento)sis.personajeelemento.elementos.get(k)).nombre,300, 310);
                             }
                    }
                    } else if (e.getY()>402 && e.getY()<484){
                    if(e.getX()>291 && e.getX()<361){
                             int k=5;
                             if (k<sis.personajeelemento.elementos.size()){
                             h.setColor(Color.GREEN );
                             h.fill3DRect(0, 300, 640, 20,false);
                             h.setColor(Color.RED );
                             //System.out.println(((Elemento)sis.personajeelemento.elementos.get(k)).nombre);
                             h.drawString(verbodefecto.getEtiqueta()+" "+((Elemento)sis.personajeelemento.elementos.get(k)).nombre,300, 310);
                             }
                    }
                    if(e.getX()>361 && e.getX()<431){
                             int k=6;
                             if (k<sis.personajeelemento.elementos.size()){
                             h.setColor(Color.GREEN );
                             h.fill3DRect(0, 300, 640, 20,false);
                             h.setColor(Color.RED );
                             //System.out.println(((Elemento)sis.personajeelemento.elementos.get(k)).nombre);
                             h.drawString(verbodefecto.getEtiqueta()+" "+((Elemento)sis.personajeelemento.elementos.get(k)).nombre,300, 310);
                             }
                    }
                    if(e.getX()>431 && e.getX()<501){
                             int k=7;
                             if (k<sis.personajeelemento.elementos.size()){
                             h.setColor(Color.GREEN );
                             h.fill3DRect(0, 300, 640, 20,false);
                             h.setColor(Color.RED );
                             //System.out.println(((Elemento)sis.personajeelemento.elementos.get(k)).nombre);
                             h.drawString(verbodefecto.getEtiqueta()+" "+((Elemento)sis.personajeelemento.elementos.get(k)).nombre,300, 310);
                             }
                    }
                    if(e.getX()>501 && e.getX()<571){
                             int k=8;
                             if (k<sis.personajeelemento.elementos.size()){
                             h.setColor(Color.GREEN );
                             h.fill3DRect(0, 300, 640, 20,false);
                             h.setColor(Color.RED );
                             //System.out.println(((Elemento)sis.personajeelemento.elementos.get(k)).nombre);
                             h.drawString(verbodefecto.getEtiqueta()+" "+((Elemento)sis.personajeelemento.elementos.get(k)).nombre,300, 310);
                             }
                    }
                    if(e.getX()>571 && e.getX()<641){
                             int k=9;
                             if (k<sis.personajeelemento.elementos.size()){
                             h.setColor(Color.GREEN );
                             h.fill3DRect(0, 300, 640, 20,false);
                             h.setColor(Color.RED );
                             //System.out.println(((Elemento)sis.personajeelemento.elementos.get(k)).nombre);
                             h.drawString(verbodefecto.getEtiqueta()+" "+((Elemento)sis.personajeelemento.elementos.get(k)).nombre,300, 310);
                             }
                    }}
            }
            if(e.getX()<261){
               //Zona de verbos
               // System.out.println(e.getX()+":"+e.getY());
                if(e.getX()<88){
                    if(e.getY()>320 && e.getY()<374){
                        h.setColor(Color.GREEN );
                        h.fill3DRect(0, 300, 640, 20,false);
                        h.setColor(Color.RED );
                        h.drawString(((Verbo)verbos.elementAt(0)).getEtiqueta(),300, 310);
                    }else if(e.getY()<418 && e.getY()>374){
                        h.setColor(Color.GREEN );
                        h.fill3DRect(0, 300, 640, 20,false);
                        h.setColor(Color.RED );
                        h.drawString(((Verbo)verbos.elementAt(1)).getEtiqueta(),300, 310);
                    }else if(e.getY()>320){
                        h.setColor(Color.GREEN );
                        h.fill3DRect(0, 300, 640, 20,false);
                        h.setColor(Color.RED );
                        h.drawString(((Verbo)verbos.elementAt(2)).getEtiqueta(),300, 310);
                    }
                }else if(e.getX()<176){
                    if(e.getY()>320 && e.getY()<374){
                        h.setColor(Color.GREEN );
                        h.fill3DRect(0, 300, 640, 20,false);
                        h.setColor(Color.RED );
                        h.drawString(((Verbo)verbos.elementAt(3)).getEtiqueta(),300, 310);
                    }else if(e.getY()<418 && e.getY()>374){
                        h.setColor(Color.GREEN );
                        h.fill3DRect(0, 300, 640, 20,false);
                        h.setColor(Color.RED );
                        h.drawString(((Verbo)verbos.elementAt(4)).getEtiqueta(),300, 310);
                    }else if(e.getY()>320){
                        h.setColor(Color.GREEN );
                        h.fill3DRect(0, 300, 640, 20,false);
                        h.setColor(Color.RED );
                        h.drawString(((Verbo)verbos.elementAt(5)).getEtiqueta(),300, 310);
                    }
                }else
                {
                    if(e.getY()>320 && e.getY()<374){
                        h.setColor(Color.GREEN );
                        h.fill3DRect(0, 300, 640, 20,false);
                        h.setColor(Color.RED );
                        h.drawString(((Verbo)verbos.elementAt(6)).getEtiqueta(),300, 310);
                    }else if(e.getY()<418 && e.getY()>374){
                        h.setColor(Color.GREEN );
                        h.fill3DRect(0, 300, 640, 20,false);
                        h.setColor(Color.RED );
                        h.drawString(((Verbo)verbos.elementAt(7)).getEtiqueta(),300, 310);
                    }else if(e.getY()>320){
                        h.setColor(Color.GREEN );
                        h.fill3DRect(0, 300, 640, 20,false);
                        h.setColor(Color.RED );
                        h.drawString(((Verbo)verbos.elementAt(8)).getEtiqueta(),300, 310);
                    }
                }
            }
        }
        }
    }}catch(NullPointerException exc){}
    }
    /**
     * Metodo que parsea las acciones de un verbo.
     * @param verb Verbo.
     * @param x Posicion x del ratón.
     * @param y Posicion y del ratón.
     */
    public void parsearVerbo(Verbo verb,int x,int y){
        Graphics2D h=(Graphics2D) super.getGraphics();
        if(verb.nombre.equals("Andar")&& pasosverbo==1 ||verb.nombre.equals("Andar") && verb==verbodefecto){
            Vector accion=new Vector();
            accion.add(1);
            accion.add(personaje);
            accion.add(cursorx);
            accion.add(cursory);
            accion.add(0);
            Vector acciones=new Vector();
            acciones.add(accion);
            EjecutarAcciones exe=new EjecutarAcciones(sis,acciones,room,super.getGraphics(),this);
            pasosverbo=0;
            fijarverbo=false;
        }else if(pasosverbo==0){
            h.setColor(Color.GREEN );
            h.fill3DRect(0, 300, 640, 20,false);
            h.setColor(Color.RED );
            verboActual=verb;
            h.drawString(verboActual.getEtiqueta(),300, 310);
            pasosverbo=1;

        }else if (pasosverbo==1){
            DibujarCajas cajas=new DibujarCajas(habitacionActual.elementos,this);
            h.setColor(Color.GREEN );
            h.fill3DRect(0, 300, 640, 20,false);
            h.setColor(Color.RED );
            h.drawString(verboActual.getEtiqueta()+" "+cajas.evaluarPosicion(x, y),300, 310);
            if(verboActual.sentencia>1){
                pasosverbo=2;
            }else if(verboActual.sentencia==1){
            pasosverbo=0;
            fijarverbo=false;
            EvaluarExpresion eval;
            if(y<320){
                if(cajas.getElemento(x, y).acciones==null){
                    eval=new EvaluarExpresion(verboActual,cajas.getElemento(x, y),globales,locales);
                }else{
                    eval=new EvaluarExpresion(verboActual,cajas.getElemento(x, y),globales,locales,cajas.getElemento(x, y).acciones);
                }
                EjecutarAcciones exe=new EjecutarAcciones(sis,eval.getAcciones(),room,super.getGraphics(),this);
            }else if(y>320 && x>291){}
                
            }
        }
    }

}
